@@ -37,8 +37,6 @@
 #include <stdlib.h>
 #include <pango/pango.h>
 
-#define GRADIENT_BAND_SIZE 4
-
 /**
  * eel_gradient_new
  * @start_color: Color for the top or left.
@@ -342,6 +340,7 @@ eel_gdk_rgba_parse_with_white_default (GdkRGBA *color,
         color->red = 1.0;
         color->green = 1.0;
         color->blue = 1.0;
+        color->alpha = 1.0;
     }
 }
 
@@ -422,9 +421,9 @@ eel_gdk_rgba_is_dark (const GdkRGBA *color)
 {
     int intensity;
 
-    intensity = ((((int) (color->red) >> 8) * 77)
-                 + (((int) (color->green) >> 8) * 150)
-                 + (((int) (color->blue) >> 8) * 28)) >> 8;
+    intensity = (((guint) (color->red * 0xff) * 77)
+                 + ((guint) (color->green * 0xff) * 150)
+                 + ((guint) (color->blue * 0xff) * 28)) >> 8;
 
     return intensity < 128;
 }
@@ -474,27 +473,6 @@ eel_gdk_parse_geometry (const char *string, int *x_return, int *y_return,
     return gdk_flags;
 }
 
-void
-eel_cairo_draw_layout_with_drop_shadow (cairo_t            *cr,
-                                        GdkRGBA            *text_color,
-                                        GdkRGBA            *shadow_color,
-                                        int                x,
-                                        int                y,
-                                        PangoLayout        *layout)
-{
-    cairo_save (cr);
-
-    gdk_cairo_set_source_rgba (cr, shadow_color);
-    cairo_move_to (cr, x+1, y+1);
-    pango_cairo_show_layout (cr, layout);
-
-    gdk_cairo_set_source_rgba (cr, text_color);
-    cairo_move_to (cr, x, y);
-    pango_cairo_show_layout (cr, layout);
-
-    cairo_restore (cr);
-}
-
 #if ! defined (EEL_OMIT_SELF_CHECK)
 
 static char *
