@@ -23,17 +23,17 @@
 */
 
 #include <config.h>
-#include "caja-bookmark.h"
+#include <gtk/gtk.h>
+#include <gio/gio.h>
 
-#include "caja-file.h"
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gtk/gtk.h>
-#include <gio/gio.h>
-#include <libcaja-private/caja-file.h>
-#include <libcaja-private/caja-icon-names.h>
+
+#include "caja-bookmark.h"
+#include "caja-file.h"
+#include "caja-icon-names.h"
 
 enum
 {
@@ -467,8 +467,7 @@ bookmark_file_changed_callback (CajaFile *file, CajaBookmark *bookmark)
 static void
 caja_bookmark_set_icon_to_default (CajaBookmark *bookmark)
 {
-    GIcon *icon, *emblemed_icon, *folder;
-    GEmblem *emblem;
+    GIcon *emblemed_icon, *folder;
 
     if (bookmark->details->icon)
     {
@@ -479,6 +478,9 @@ caja_bookmark_set_icon_to_default (CajaBookmark *bookmark)
 
     if (caja_bookmark_uri_known_not_to_exist (bookmark))
     {
+        GIcon *icon;
+        GEmblem *emblem;
+
         icon = g_themed_icon_new ("dialog-warning");
         emblem = g_emblem_new (icon);
 
@@ -585,20 +587,6 @@ caja_bookmark_new (GFile *location, const char *name, gboolean has_custom_name,
     return new_bookmark;
 }
 
-static cairo_surface_t *
-create_image_cairo_for_bookmark (CajaBookmark *bookmark)
-{
-    cairo_surface_t *surface;
-
-    surface = caja_bookmark_get_surface (bookmark, GTK_ICON_SIZE_MENU);
-    if (surface == NULL)
-    {
-        return NULL;
-    }
-
-    return surface;
-}
-
 static GtkWidget *
 bookmark_image_menu_item_new_from_surface (cairo_surface_t   *icon_surface,
                                            const gchar       *label_name)
@@ -624,10 +612,10 @@ bookmark_image_menu_item_new_from_surface (cairo_surface_t   *icon_surface,
     gtk_label_set_max_width_chars (label, (ELLIPSISED_MENU_ITEM_MIN_CHARS + 2));
 
     GtkWidget *menuitem = gtk_menu_item_new ();
- 
+
     gtk_container_add (GTK_CONTAINER (box), icon);
     gtk_container_add (GTK_CONTAINER (box), label_menu);
- 
+
     gtk_container_add (GTK_CONTAINER (menuitem), box);
     gtk_widget_show_all (menuitem);
 
@@ -644,19 +632,24 @@ bookmark_image_menu_item_new_from_surface (cairo_surface_t   *icon_surface,
 GtkWidget *
 caja_bookmark_menu_item_new (CajaBookmark *bookmark)
 {
-    GtkWidget *menu_item;
-    cairo_surface_t *image_cairo;
-
-    image_cairo = create_image_cairo_for_bookmark (bookmark);
+    GtkWidget *menu_item = NULL;
 
     if (strlen (bookmark->details->name) > 0)
     {
-        menu_item = bookmark_image_menu_item_new_from_surface (image_cairo, bookmark->details->name);
+        cairo_surface_t *surface;
 
-        return menu_item;
+        surface =
+            caja_bookmark_get_surface (bookmark,
+                                       GTK_ICON_SIZE_MENU);
+        menu_item =
+            bookmark_image_menu_item_new_from_surface (surface,
+                                                       bookmark->details->name);
+        if (surface != NULL)
+        {
+            cairo_surface_destroy (surface);
+        }
     }
-    else
-        return NULL;
+    return menu_item;
 }
 
 gboolean
