@@ -64,9 +64,11 @@ G_BEGIN_DECLS
 
 /* Display  */
 #define CAJA_PREFERENCES_SHOW_HIDDEN_FILES  		"show-hidden-files"
+#define CAJA_PREFERENCES_SHOW_BACKUP_FILES  		"show-backup-files"
 #define CAJA_PREFERENCES_SHOW_ADVANCED_PERMISSIONS	"show-advanced-permissions"
 #define CAJA_PREFERENCES_DATE_FORMAT			"date-format"
 #define CAJA_PREFERENCES_USE_IEC_UNITS			"use-iec-units"
+#define CAJA_PREFERENCES_SHOW_ICONS_IN_LIST_VIEW	"show-icons-in-list-view"
 
 /* Mouse */
 #define CAJA_PREFERENCES_MOUSE_USE_EXTRA_BUTTONS 	"mouse-use-extra-buttons"
@@ -210,18 +212,18 @@ typedef enum
 void caja_global_preferences_init                      (void);
 char *caja_global_preferences_get_default_folder_viewer_preference_as_iid (void);
 
-GSettings *caja_preferences;
-GSettings *caja_media_preferences;
-GSettings *caja_window_state;
-GSettings *caja_icon_view_preferences;
-GSettings *caja_desktop_preferences;
-GSettings *caja_tree_sidebar_preferences;
-GSettings *caja_compact_view_preferences;
-GSettings *caja_list_view_preferences;
-GSettings *caja_extension_preferences;
+extern GSettings *caja_preferences;
+extern GSettings *caja_media_preferences;
+extern GSettings *caja_window_state;
+extern GSettings *caja_icon_view_preferences;
+extern GSettings *caja_desktop_preferences;
+extern GSettings *caja_tree_sidebar_preferences;
+extern GSettings *caja_compact_view_preferences;
+extern GSettings *caja_list_view_preferences;
+extern GSettings *caja_extension_preferences;
 
-GSettings *mate_background_preferences;
-GSettings *mate_lockdown_preferences;
+extern GSettings *mate_background_preferences;
+extern GSettings *mate_lockdown_preferences;
 
 G_END_DECLS
 
