@@ -24,9 +24,10 @@
  */
 
 #include <config.h>
-#include "caja-information-panel.h"
 
-#include "caja-sidebar-title.h"
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
 
 #include <eel/eel-background.h>
 #include <eel/eel-glib-extensions.h>
@@ -34,9 +35,7 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
+
 #include <libcaja-private/caja-dnd.h>
 #include <libcaja-private/caja-directory.h>
 #include <libcaja-private/caja-file-dnd.h>
@@ -49,6 +48,9 @@
 #include <libcaja-private/caja-sidebar-provider.h>
 #include <libcaja-private/caja-module.h>
 
+#include "caja-information-panel.h"
+#include "caja-sidebar-title.h"
+
 struct _CajaInformationPanelPrivate
 {
     GtkWidget *container;
@@ -89,7 +91,6 @@ static void     caja_information_panel_update_appearance     (CajaInformationPan
 static void     caja_information_panel_update_buttons        (CajaInformationPanel     *information_panel);
 static void     background_metadata_changed_callback             (CajaInformationPanel     *information_panel);
 static void     caja_information_panel_iface_init            (CajaSidebarIface         *iface);
-static void     caja_information_panel_iface_init            (CajaSidebarIface         *iface);
 static void     sidebar_provider_iface_init                      (CajaSidebarProviderIface *iface);
 static GType    caja_information_panel_provider_get_type     (void);
 
@@ -483,7 +484,6 @@ receive_dropped_uri_list (CajaInformationPanel *information_panel,
     char **uris;
     gboolean exactly_one;
     GtkWindow *window;
-    EelBackground *background;
 
     uris = g_uri_list_extract_uris ((gchar *) gtk_selection_data_get_data (selection_data));
     exactly_one = uris[0] != NULL && (uris[1] == NULL || uris[1][0] == '\0');
@@ -506,6 +506,8 @@ receive_dropped_uri_list (CajaInformationPanel *information_panel,
 
             if (action > 0)
             {
+                EelBackground *background;
+
                 background = eel_get_widget_background (GTK_WIDGET (information_panel));
                 eel_background_set_dropped_image (background, action, uris[0]);
             }
@@ -577,7 +579,6 @@ receive_dropped_color (CajaInformationPanel *information_panel,
 {
     guint16 *channels;
     char color_spec[8];
-    EelBackground *background;
 
     if (gtk_selection_data_get_length (selection_data) != 8 ||
             gtk_selection_data_get_format (selection_data) != 16)
@@ -605,6 +606,8 @@ receive_dropped_color (CajaInformationPanel *information_panel,
 
         if (action > 0)
         {
+            EelBackground *background;
+
             background = eel_get_widget_background (GTK_WIDGET (information_panel));
             eel_background_set_dropped_color (background, GTK_WIDGET (information_panel),
                                               action, x, y, selection_data);
@@ -677,7 +680,6 @@ static gboolean
 caja_information_panel_press_event (GtkWidget *widget, GdkEventButton *event)
 {
     CajaInformationPanel *information_panel;
-    GtkWidget *menu;
 
     if (gtk_widget_get_window (widget) != event->window)
     {
@@ -689,6 +691,8 @@ caja_information_panel_press_event (GtkWidget *widget, GdkEventButton *event)
     /* handle the context menu */
     if (event->button == CONTEXTUAL_MENU_BUTTON)
     {
+        GtkWidget *menu;
+
         menu = caja_information_panel_create_context_menu (information_panel);
         eel_pop_up_context_menu (GTK_MENU(menu),
                                  event);
@@ -696,162 +700,6 @@ caja_information_panel_press_event (GtkWidget *widget, GdkEventButton *event)
     return TRUE;
 }
 
-static gboolean
-value_different (const char *a, const char *b)
-{
-    if (!a && !b)
-        return FALSE;
-
-    if (!a || !b)
-        return TRUE;
-
-    return strcmp (a, b);
-}
-
-/* Handle the background changed signal by writing out the settings to metadata.
- */
-static void
-background_settings_changed_callback (EelBackground *background, GdkDragAction action, CajaInformationPanel *information_panel)
-{
-    char *image;
-    char *color;
-
-    g_assert (EEL_IS_BACKGROUND (background));
-    g_assert (CAJA_IS_INFORMATION_PANEL (information_panel));
-
-    if (information_panel->details->file == NULL)
-    {
-        return;
-    }
-
-    /* Block so we don't respond to our own metadata changes.
-     */
-    g_signal_handlers_block_by_func (information_panel->details->file,
-                                     G_CALLBACK (background_metadata_changed_callback),
-                                     information_panel);
-
-    color = eel_background_get_color (background);
-    image = eel_background_get_image_uri (background);
-
-    if (action != (GdkDragAction) CAJA_DND_ACTION_SET_AS_BACKGROUND)
-    {
-        caja_file_set_metadata (information_panel->details->file,
-                                CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR,
-                                NULL,
-                                NULL);
-
-        caja_file_set_metadata (information_panel->details->file,
-                                CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_IMAGE,
-                                NULL,
-                                NULL);
-
-        g_signal_handlers_block_by_func (caja_preferences,
-                         G_CALLBACK(caja_information_panel_theme_changed),
-                         information_panel);
-        g_settings_set_string (caja_preferences,
-                       CAJA_PREFERENCES_SIDE_PANE_BACKGROUND_COLOR, color ? color : "");
-        g_settings_set_string (caja_preferences,
-                       CAJA_PREFERENCES_SIDE_PANE_BACKGROUND_URI, image ? image : "");
-        g_settings_set_boolean (caja_preferences,
-                    CAJA_PREFERENCES_SIDE_PANE_BACKGROUND_SET, TRUE);
-        g_signal_handlers_unblock_by_func (caja_preferences,
-                           G_CALLBACK(caja_information_panel_theme_changed),
-                           information_panel);
-    }
-    else
-    {
-        caja_file_set_metadata (information_panel->details->file,
-                                CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR,
-                                NULL,
-                                color);
-
-        caja_file_set_metadata (information_panel->details->file,
-                                CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_IMAGE,
-                                NULL,
-                                image);
-    }
-
-    if (value_different (information_panel->details->current_background_color, color))
-    {
-        g_free (information_panel->details->current_background_color);
-        information_panel->details->current_background_color = g_strdup (color);
-    }
-
-    if (value_different (information_panel->details->current_background_image, image))
-    {
-        g_free (information_panel->details->current_background_image);
-        information_panel->details->current_background_image = g_strdup (image);
-    }
-
-    g_free (color);
-    g_free (image);
-
-    g_signal_handlers_unblock_by_func (information_panel->details->file,
-                                       G_CALLBACK (background_metadata_changed_callback),
-                                       information_panel);
-}
-
-/* handle the background reset signal by writing out NULL to metadata and setting the backgrounds
-   fields to their default values */
-static void
-background_reset_callback (EelBackground *background, CajaInformationPanel *information_panel)
-{
-    char *color;
-    char *image;
-    g_assert (EEL_IS_BACKGROUND (background));
-    g_assert (CAJA_IS_INFORMATION_PANEL (information_panel));
-
-    if (information_panel->details->file == NULL)
-    {
-        return;
-    }
-
-    /* Block so we don't respond to our own metadata changes.
-     */
-    g_signal_handlers_block_by_func (information_panel->details->file,
-                                     G_CALLBACK (background_metadata_changed_callback),
-                                     information_panel);
-
-    color = caja_file_get_metadata (information_panel->details->file,
-                                    CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR,
-                                    NULL);
-
-    image = caja_file_get_metadata (information_panel->details->file,
-                                    CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_IMAGE,
-                                    NULL);
-    if (color || image)
-    {
-        caja_file_set_metadata (information_panel->details->file,
-                                CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR,
-                                NULL,
-                                NULL);
-
-        caja_file_set_metadata (information_panel->details->file,
-                                CAJA_METADATA_KEY_SIDEBAR_BACKGROUND_IMAGE,
-                                NULL,
-                                NULL);
-    }
-    else
-    {
-        g_signal_handlers_block_by_func (caja_preferences,
-                         G_CALLBACK(caja_information_panel_theme_changed),
-                         information_panel);
-        g_settings_set_boolean (caja_preferences,
-                    CAJA_PREFERENCES_SIDE_PANE_BACKGROUND_SET, FALSE);
-        g_signal_handlers_unblock_by_func (caja_preferences,
-                         G_CALLBACK(caja_information_panel_theme_changed),
-                         information_panel);
-    }
-
-    g_signal_handlers_unblock_by_func (information_panel->details->file,
-                                       G_CALLBACK (background_metadata_changed_callback),
-                                       information_panel);
-
-    /* Force a read from the metadata to set the defaults
-     */
-    background_metadata_changed_callback (information_panel);
-}
-
 static GtkWindow *
 caja_information_panel_get_window (CajaInformationPanel *information_panel)
 {
@@ -925,7 +773,6 @@ static void
 add_buttons_from_metadata (CajaInformationPanel *information_panel, const char *button_data)
 {
     char **terms;
-    char *current_term, *temp_str;
     char *button_name, *command_string;
     const char *term;
     int index;
@@ -938,6 +785,8 @@ add_buttons_from_metadata (CajaInformationPanel *information_panel, const char *
     /* for each term, either create a button or attach a property to one */
     for (index = 0; (term = terms[index]) != NULL; index++)
     {
+        char *current_term, *temp_str;
+
         current_term = g_strdup (term);
         temp_str = strchr (current_term, '=');
         if (temp_str)
@@ -990,7 +839,6 @@ static void
 caja_information_panel_update_buttons (CajaInformationPanel *information_panel)
 {
     char *button_data;
-    GAppInfo *default_app;
 
     /* dispose of any existing buttons */
     if (information_panel->details->has_buttons)
@@ -1014,6 +862,8 @@ caja_information_panel_update_buttons (CajaInformationPanel *information_panel)
     if (caja_mime_has_any_applications_for_file (information_panel->details->file) &&
             !caja_file_is_directory (information_panel->details->file))
     {
+        GAppInfo *default_app;
+
         default_app =
             caja_mime_get_default_application_for_file (information_panel->details->file);
         add_command_button (information_panel, default_app);
@@ -1140,8 +990,6 @@ selection_changed_callback (CajaWindowInfo *window,
 {
     int selection_count;
     GList *selection;
-    GFile *selected;
-    CajaFile *file;
     char *uri, *name;
 
     selection = caja_window_info_get_selection (window);
@@ -1149,6 +997,9 @@ selection_changed_callback (CajaWindowInfo *window,
 
     if (selection_count == 1)
     {
+        GFile *selected;
+        CajaFile *file;
+
         selection = caja_window_info_get_selection (window);
         selected = selection->data;
 
