@@ -608,7 +608,7 @@ action_new_window_callback (GtkAction *action,
 {
     CajaWindow *current_window;
 
-    current_window = CAJA_WINDOW (user_data);   
+    current_window = CAJA_WINDOW (user_data);
     caja_window_new_window (current_window);
 }
 
@@ -824,9 +824,15 @@ action_tab_change_action_activate_callback (GtkAction *action, gpointer user_dat
 
 static const GtkActionEntry navigation_entries[] =
 {
-    /* name, icon name, label */ { "Go", NULL, N_("_Go") },
-    /* name, icon name, label */ { "Bookmarks", NULL, N_("_Bookmarks") },
-    /* name, icon name, label */ { "Tabs", NULL, N_("_Tabs") },
+    /* name, icon name, label */ { "Go", NULL, N_("_Go"),
+        NULL, NULL, NULL
+    },
+    /* name, icon name, label */ { "Bookmarks", NULL, N_("_Bookmarks"),
+        NULL, NULL, NULL
+    },
+    /* name, icon name, label */ { "Tabs", NULL, N_("_Tabs"),
+        NULL, NULL, NULL
+    },
     /* name, icon name, label */ { "New Window", "window-new", N_("New _Window"),
         "<control>N", N_("Open another Caja window for the displayed location"),
         G_CALLBACK (action_new_window_callback)
@@ -946,7 +952,9 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
 
     G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("NavigationActions");
+#ifdef ENABLE_NLS
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
     window->details->navigation_action_group = action_group;
     gtk_action_group_add_actions (action_group,
                                   navigation_entries, G_N_ELEMENTS (navigation_entries),
