@@ -22,6 +22,13 @@
    Author: Holger Berndt <berndth@gmx.de>
 */
 
+#include <eel/eel-gtk-extensions.h>
+
+#include <libcaja-private/caja-global-preferences.h>
+#include <libcaja-private/caja-window-slot-info.h>
+#include <libcaja-private/caja-view-factory.h>
+#include <libcaja-private/caja-entry.h>
+
 #include "caja-navigation-window-pane.h"
 #include "caja-window-private.h"
 #include "caja-window-manage-views.h"
@@ -30,16 +37,6 @@
 #include "caja-notebook.h"
 #include "caja-window-slot.h"
 
-#include <eel/eel-gtk-extensions.h>
-
-#include <libcaja-private/caja-global-preferences.h>
-#include <libcaja-private/caja-window-slot-info.h>
-#include <libcaja-private/caja-view-factory.h>
-#include <libcaja-private/caja-entry.h>
-
-
-static void caja_navigation_window_pane_init       (CajaNavigationWindowPane *pane);
-static void caja_navigation_window_pane_class_init (CajaNavigationWindowPaneClass *class);
 static void caja_navigation_window_pane_dispose    (GObject *object);
 
 G_DEFINE_TYPE (CajaNavigationWindowPane,
@@ -63,7 +60,7 @@ real_set_active (CajaWindowPane *pane, gboolean is_active)
 
     /* navigation bar (manual entry) */
     caja_location_bar_set_active (CAJA_LOCATION_BAR (nav_pane->navigation_bar), is_active);
-    
+
     /* location button */
     gtk_widget_set_sensitive (gtk_bin_get_child (GTK_BIN (nav_pane->location_button)), is_active);
 }
@@ -80,10 +77,10 @@ navigation_bar_focus_in_callback (GtkWidget *widget, GdkEventFocus *event, gpoin
 static int
 bookmark_list_get_uri_index (GList *list, GFile *location)
 {
-    CajaBookmark *bookmark;
     GList *l;
-    GFile *tmp;
     int i;
+    CajaBookmark *bookmark = NULL;
+    GFile *tmp = NULL;
 
     g_return_val_if_fail (location != NULL, -1);
 
@@ -115,7 +112,7 @@ static void
 search_bar_activate_callback (CajaSearchBar *bar,
                               CajaNavigationWindowPane *pane)
 {
-    char *uri, *current_uri;
+    char *uri;
     CajaDirectory *directory;
     CajaSearchDirectory *search_directory;
     CajaQuery *query;
@@ -137,6 +134,8 @@ search_bar_activate_callback (CajaSearchBar *bar,
         CajaWindowSlot *slot = CAJA_WINDOW_PANE (pane)->active_slot;
         if (!caja_search_directory_is_indexed (search_directory))
         {
+            char *current_uri;
+
             current_uri = caja_window_slot_get_location_uri (slot);
             caja_query_set_location (query, current_uri);
             g_free (current_uri);
@@ -203,6 +202,9 @@ path_bar_location_changed_callback (GtkWidget *widget,
 
     slot = CAJA_NAVIGATION_WINDOW_SLOT (win_pane->active_slot);
 
+    /* Make sure we are changing the location on the correct pane */
+    caja_window_set_active_pane (CAJA_WINDOW_PANE (pane)->window, CAJA_WINDOW_PANE (pane));
+
     /* check whether we already visited the target location */
     i = bookmark_list_get_uri_index (slot->back_list, location);
     if (i >= 0)
@@ -269,11 +271,10 @@ path_bar_path_event_callback (CajaPathBar *path_bar,
 {
     CajaWindowSlot *slot;
     CajaWindowOpenFlags flags;
-    int mask;
-    CajaView *view;
-    char *uri;
 
     if (event->type == GDK_BUTTON_RELEASE) {
+        int mask;
+
         mask = event->state & gtk_accelerator_get_default_mod_mask ();
         flags = 0;
 
@@ -298,9 +299,14 @@ path_bar_path_event_callback (CajaPathBar *path_bar,
     }
 
     if (event->button == 3) {
+        CajaView *view;
+
         slot = caja_window_get_active_slot (pane->window);
         view = slot->content_view;
+
         if (view != NULL) {
+            char *uri;
+
             uri = g_file_get_uri (location);
             caja_view_pop_up_location_context_menu (view, event, uri);
             g_free (uri);
@@ -482,7 +488,7 @@ notebook_switch_page_cb (GtkNotebook *notebook,
     g_assert (slot != NULL);
 
     caja_window_set_active_slot (slot->pane->window, slot);
-    
+
     caja_window_slot_update_icon (slot);
 
     return FALSE;
@@ -526,7 +532,6 @@ caja_navigation_window_pane_add_slot_in_tab (CajaNavigationWindowPane *pane, Caj
 static void
 real_sync_location_widgets (CajaWindowPane *pane)
 {
-    CajaNavigationWindowSlot *navigation_slot;
     CajaNavigationWindowPane *navigation_pane;
     CajaWindowSlot *slot;
 
@@ -548,6 +553,8 @@ real_sync_location_widgets (CajaWindowPane *pane)
     /* Update window global UI if this is the active pane */
     if (pane == pane->window->details->active_pane)
     {
+        CajaNavigationWindowSlot *navigation_slot;
+
         caja_window_update_up_button (pane->window);
 
         /* Check if the back and forward buttons need enabling or disabling. */
@@ -563,7 +570,6 @@ gboolean
 caja_navigation_window_pane_hide_temporary_bars (CajaNavigationWindowPane *pane)
 {
     CajaWindowSlot *slot;
-    CajaDirectory *directory;
     gboolean success;
 
     g_assert (CAJA_IS_NAVIGATION_WINDOW_PANE (pane));
@@ -582,6 +588,8 @@ caja_navigation_window_pane_hide_temporary_bars (CajaNavigationWindowPane *pane)
     }
     if (pane->temporary_navigation_bar)
     {
+        CajaDirectory *directory;
+
         directory = caja_directory_get (slot->location);
 
         if (CAJA_IS_SEARCH_DIRECTORY (directory))
@@ -632,7 +640,7 @@ caja_navigation_window_pane_always_use_location_entry (CajaNavigationWindowPane
     {
         caja_navigation_window_pane_set_bar_mode (pane, CAJA_BAR_PATH);
     }
-    
+
     g_signal_handlers_block_by_func (pane->location_button,
                                      G_CALLBACK (location_button_toggled_cb),
                                      pane);
@@ -798,7 +806,7 @@ caja_navigation_window_pane_set_bar_mode (CajaNavigationWindowPane *pane,
         gtk_widget_hide (pane->navigation_bar);
         break;
     }
-    
+
     if (mode == CAJA_BAR_NAVIGATION || mode == CAJA_BAR_PATH) {
         use_entry = (mode == CAJA_BAR_NAVIGATION);
 
