@@ -26,23 +26,15 @@
  *                           split into separate file just for convenience.
  */
 #include <config.h>
-
 #include <locale.h>
+#include <string.h>
 
-#include "caja-actions.h"
-#include "caja-application.h"
-#include "caja-connect-server-dialog.h"
-#include "caja-file-management-properties.h"
-#include "caja-property-browser.h"
-#include "caja-window-manage-views.h"
-#include "caja-window-bookmarks.h"
-#include "caja-window-private.h"
-#include "caja-desktop-window.h"
-#include "caja-search-bar.h"
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
+
 #include <eel/eel-gtk-extensions.h>
+
 #include <libcaja-extension/caja-menu-provider.h>
 #include <libcaja-private/caja-extensions.h>
 #include <libcaja-private/caja-file-utilities.h>
@@ -54,7 +46,17 @@
 #include <libcaja-private/caja-search-engine.h>
 #include <libcaja-private/caja-signaller.h>
 #include <libcaja-private/caja-trash-monitor.h>
-#include <string.h>
+
+#include "caja-actions.h"
+#include "caja-application.h"
+#include "caja-connect-server-dialog.h"
+#include "caja-file-management-properties.h"
+#include "caja-property-browser.h"
+#include "caja-window-manage-views.h"
+#include "caja-window-bookmarks.h"
+#include "caja-window-private.h"
+#include "caja-desktop-window.h"
+#include "caja-search-bar.h"
 
 #define MENU_PATH_EXTENSION_ACTIONS                     "/MenuBar/File/Extension Actions"
 #define POPUP_PATH_EXTENSION_ACTIONS                     "/background/Before Zoom Items/Extension Actions"
@@ -139,9 +141,7 @@ should_open_in_new_tab (void)
 static void
 activate_bookmark_in_menu_item (GtkAction *action, gpointer user_data)
 {
-    CajaWindowSlot *slot;
     BookmarkHolder *holder;
-    GFile *location;
 
     holder = (BookmarkHolder *)user_data;
 
@@ -151,6 +151,9 @@ activate_bookmark_in_menu_item (GtkAction *action, gpointer user_data)
     }
     else
     {
+        CajaWindowSlot *slot;
+        GFile *location;
+
         location = caja_bookmark_get_location (holder->bookmark);
         slot = caja_window_get_active_slot (holder->window);
         caja_window_slot_go_to (slot,
@@ -190,22 +193,26 @@ caja_menus_append_bookmark_to_menu (CajaWindow *window,
 
     g_snprintf (action_name, sizeof (action_name), "%s%d", parent_id, index_in_parent);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_new (action_name,
                              name,
                              _("Go to the location specified by this bookmark"),
                              NULL);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     g_object_set_data_full (G_OBJECT (action), "menu-icon",
                             cairo_surface_reference (surface),
-                            cairo_surface_destroy);
+                            (GDestroyNotify)cairo_surface_destroy);
 
     g_signal_connect_data (action, "activate",
                            G_CALLBACK (activate_bookmark_in_menu_item),
                            bookmark_holder,
                            bookmark_holder_free_cover, 0);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_action_group_add_action (action_group,
                                  GTK_ACTION (action));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     g_object_unref (action);
 
@@ -359,7 +366,7 @@ static void
 action_reload_callback (GtkAction *action,
                         gpointer user_data)
 {
-    caja_window_reload (CAJA_WINDOW (user_data));
+    caja_window_reload (CAJA_WINDOW (user_data), should_open_in_new_tab ());
 }
 
 static void
@@ -392,6 +399,7 @@ action_show_hidden_files_callback (GtkAction *action,
 
     window = CAJA_WINDOW (callback_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
     {
         mode = CAJA_WINDOW_SHOW_HIDDEN_FILES_ENABLE;
@@ -400,20 +408,46 @@ action_show_hidden_files_callback (GtkAction *action,
     {
         mode = CAJA_WINDOW_SHOW_HIDDEN_FILES_DISABLE;
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     caja_window_info_set_hidden_files_mode (window, mode);
 }
 
+static void
+action_show_backup_files_callback (GtkAction *action,
+                                   gpointer callback_data)
+{
+    CajaWindow *window;
+    CajaWindowShowBackupFilesMode mode;
+
+    window = CAJA_WINDOW (callback_data);
+
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+    if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
+    {
+        mode = CAJA_WINDOW_SHOW_BACKUP_FILES_ENABLE;
+    }
+    else
+    {
+        mode = CAJA_WINDOW_SHOW_BACKUP_FILES_DISABLE;
+    }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
+
+    caja_window_info_set_backup_files_mode (window, mode);
+}
+
 static void
 show_hidden_files_preference_callback (gpointer callback_data)
 {
     CajaWindow *window;
-    GtkAction *action;
 
     window = CAJA_WINDOW (callback_data);
 
     if (window->details->show_hidden_files_mode == CAJA_WINDOW_SHOW_HIDDEN_FILES_DEFAULT)
     {
+        GtkAction *action;
+
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         action = gtk_action_group_get_action (window->details->main_action_group, CAJA_ACTION_SHOW_HIDDEN_FILES);
         g_assert (GTK_IS_ACTION (action));
 
@@ -421,6 +455,7 @@ show_hidden_files_preference_callback (gpointer callback_data)
         g_signal_handlers_block_by_func (action, action_show_hidden_files_callback, window);
         gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                       g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_SHOW_HIDDEN_FILES));
+        G_GNUC_END_IGNORE_DEPRECATIONS;
         g_signal_handlers_unblock_by_func (action, action_show_hidden_files_callback, window);
 
         /* inform views */
@@ -429,6 +464,33 @@ show_hidden_files_preference_callback (gpointer callback_data)
     }
 }
 
+static void
+show_backup_files_preference_callback (gpointer callback_data)
+{
+    CajaWindow *window;
+
+    window = CAJA_WINDOW (callback_data);
+
+    if (window->details->show_backup_files_mode == CAJA_WINDOW_SHOW_BACKUP_FILES_DEFAULT)
+    {
+        GtkAction *action;
+
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+        action = gtk_action_group_get_action (window->details->main_action_group, CAJA_ACTION_SHOW_BACKUP_FILES);
+        g_assert (GTK_IS_ACTION (action));
+
+        /* update button */
+        g_signal_handlers_block_by_func (action, action_show_backup_files_callback, window);
+        gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                      g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_SHOW_BACKUP_FILES));
+        G_GNUC_END_IGNORE_DEPRECATIONS;
+        g_signal_handlers_unblock_by_func (action, action_show_backup_files_callback, window);
+
+        /* inform views */
+        caja_window_info_set_backup_files_mode (window, CAJA_WINDOW_SHOW_BACKUP_FILES_DEFAULT);
+    }
+}
+
 static void
 preferences_respond_callback (GtkDialog *dialog,
                               gint response_id)
@@ -461,57 +523,13 @@ action_backgrounds_and_emblems_callback (GtkAction *action,
     caja_property_browser_show (gtk_window_get_screen (window));
 }
 
+#define ABOUT_GROUP "About"
+#define EMAILIFY(string) (g_strdelimit ((string), "%", '@'))
+
 static void
 action_about_caja_callback (GtkAction *action,
                             gpointer user_data)
 {
-    const gchar *authors[] =
-    {
-        "Alexander Larsson",
-        "Ali Abdin",
-        "Anders Carlsson",
-        "Andy Hertzfeld",
-        "Arlo Rose",
-        "Darin Adler",
-        "David Camp",
-        "Eli Goldberg",
-        "Elliot Lee",
-        "Eskil Heyn Olsen",
-        "Ettore Perazzoli",
-        "Gene Z. Ragan",
-        "George Lebl",
-        "Ian McKellar",
-        "J Shane Culpepper",
-        "James Willcox",
-        "Jan Arne Petersen",
-        "John Harper",
-        "John Sullivan",
-        "Josh Barrow",
-        "Maciej Stachowiak",
-        "Mark McLoughlin",
-        "Mathieu Lacage",
-        "Mike Engber",
-        "Mike Fleming",
-        "Pavel Cisler",
-        "Ramiro Estrugo",
-        "Raph Levien",
-        "Rebecca Schulman",
-        "Robey Pointer",
-        "Robin * Slomkowski",
-        "Seth Nickell",
-        "Susan Kare",
-        "Perberos",
-        "Steve Zesch",
-        "Stefano Karapetsas",
-        "Jasmine Hassan",
-        NULL
-    };
-    const gchar *documenters[] =
-    {
-        "GNOME Documentation Team",
-        "Sun Microsystem",
-        NULL
-    };
     const gchar *license[] =
     {
         N_("Caja is free software; you can redistribute it and/or modify "
@@ -527,32 +545,52 @@ action_about_caja_callback (GtkAction *action,
         "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA")
     };
     gchar *license_trans;
+    GKeyFile *key_file;
+    GError *error = NULL;
+    char **authors, **documenters;
+    gsize n_authors = 0, n_documenters = 0 , i;
 
-    license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
-                               _(license[2]), NULL);
+    key_file = g_key_file_new ();
+    if (!g_key_file_load_from_file (key_file, CAJA_DATADIR G_DIR_SEPARATOR_S "caja.about", 0, &error))
+    {
+        g_warning ("Couldn't load about data: %s\n", error->message);
+        g_error_free (error);
+        g_key_file_free (key_file);
+        return;
+    }
+
+    authors = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Authors", &n_authors, NULL);
+    documenters = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Documenters", &n_documenters, NULL);
+    g_key_file_free (key_file);
+
+    for (i = 0; i < n_authors; ++i)
+        authors[i] = EMAILIFY (authors[i]);
+    for (i = 0; i < n_documenters; ++i)
+        documenters[i] = EMAILIFY (documenters[i]);
+
+    license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]), _(license[2]), NULL);
 
     gtk_show_about_dialog (GTK_WINDOW (user_data),
                            "program-name", _("Caja"),
+                           "title", _("About Caja"),
                            "version", VERSION,
                            "comments", _("Caja lets you organize "
                                          "files and folders, both on "
                                          "your computer and online."),
                            "copyright", _("Copyright \xC2\xA9 1999-2009 The Nautilus authors\n"
-                                          "Copyright \xC2\xA9 2011-2018 The Caja authors"),
+                                          "Copyright \xC2\xA9 2011-2021 The Caja authors"),
                            "license", license_trans,
                            "wrap-license", TRUE,
                            "authors", authors,
                            "documenters", documenters,
-                           /* Translators should localize the following string
-                            * which will be displayed at the bottom of the about
-                            * box to give credit to the translator(s).
-                            */
                            "translator-credits", _("translator-credits"),
                            "logo-icon-name", "system-file-manager",
-                           "website", "http://www.mate-desktop.org",
-                           "website-label", _("MATE Web Site"),
+                           "website", PACKAGE_URL,
+                           "website-label", _("Website"),
                            NULL);
 
+    g_strfreev (authors);
+    g_strfreev (documenters);
     g_free (license_trans);
 
 }
@@ -570,7 +608,6 @@ action_caja_manual_callback (GtkAction *action,
 {
     CajaWindow *window;
     GError *error;
-    GtkWidget *dialog;
 
     error = NULL;
     window = CAJA_WINDOW (user_data);
@@ -583,6 +620,8 @@ action_caja_manual_callback (GtkAction *action,
 
     if (error)
     {
+        GtkWidget *dialog;
+
         dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                                          GTK_DIALOG_MODAL,
                                          GTK_MESSAGE_ERROR,
@@ -606,7 +645,9 @@ menu_item_select_cb (GtkMenuItem *proxy,
     GtkAction *action;
     char *message;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (proxy));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     g_return_if_fail (action != NULL);
 
     g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
@@ -776,8 +817,10 @@ trash_state_changed_cb (CajaTrashMonitor *monitor,
     GtkAction *action;
     GIcon *gicon;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = window->details->main_action_group;
     action = gtk_action_group_get_action (action_group, "Go to Trash");
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     gicon = caja_trash_monitor_get_icon ();
 
@@ -803,10 +846,14 @@ caja_window_initialize_trash_icon_monitor (CajaWindow *window)
 
 static const GtkActionEntry main_entries[] =
 {
-    /* name, icon name, label */ { "File", NULL, N_("_File") },
-    /* name, icon name, label */ { "Edit", NULL, N_("_Edit") },
-    /* name, icon name, label */ { "View", NULL, N_("_View") },
-    /* name, icon name, label */ { "Help", NULL, N_("_Help") },
+    /* name, icon name, label */ { "File", NULL, N_("_File"),
+                                   NULL, NULL, NULL },
+    /* name, icon name, label */ { "Edit", NULL, N_("_Edit"),
+                                   NULL, NULL, NULL },
+    /* name, icon name, label */ { "View", NULL, N_("_View"),
+                                   NULL, NULL, NULL },
+    /* name, icon name, label */ { "Help", NULL, N_("_Help"),
+                                   NULL, NULL, NULL },
     /* name, icon name */        { "Close", "window-close",
         /* label, accelerator */       N_("_Close"), "<control>W",
         /* tooltip */                  N_("Close this folder"),
@@ -922,6 +969,13 @@ static const GtkToggleActionEntry main_toggle_entries[] =
         G_CALLBACK (action_show_hidden_files_callback),
         TRUE
     },
+    /* name, stock id */         { "Show Backup Files", NULL,
+    /* label, accelerator */       N_("Show Bac_kup Files"), "<control>K",
+    /* tooltip */                  N_("Toggle the display of backup files in the current window"),
+        G_CALLBACK (action_show_backup_files_callback),
+        TRUE
+    },
+
 };
 
 /**
@@ -938,8 +992,11 @@ caja_window_initialize_menus (CajaWindow *window)
     GtkAction *action;
     const char *ui;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("ShellActions");
+#ifdef ENABLE_NLS
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
     window->details->main_action_group = action_group;
     gtk_action_group_add_actions (action_group,
                                   main_entries, G_N_ELEMENTS (main_entries),
@@ -959,12 +1016,21 @@ caja_window_initialize_menus (CajaWindow *window)
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                   g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_SHOW_HIDDEN_FILES));
     g_signal_handlers_unblock_by_func (action, action_show_hidden_files_callback, window);
-
-
     g_signal_connect_swapped (caja_preferences, "changed::" CAJA_PREFERENCES_SHOW_HIDDEN_FILES,
                               G_CALLBACK(show_hidden_files_preference_callback),
                               window);
 
+    action = gtk_action_group_get_action (action_group, CAJA_ACTION_SHOW_BACKUP_FILES);
+    g_signal_handlers_block_by_func (action, action_show_backup_files_callback, window);
+    gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                  g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_SHOW_BACKUP_FILES));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
+    g_signal_handlers_unblock_by_func (action, action_show_backup_files_callback, window);
+
+    g_signal_connect_swapped (caja_preferences, "changed::" CAJA_PREFERENCES_SHOW_BACKUP_FILES,
+                              G_CALLBACK(show_backup_files_preference_callback),
+                              window);
+
     window->details->ui_manager = gtk_ui_manager_new ();
     ui_manager = window->details->ui_manager;
     gtk_window_add_accel_group (GTK_WINDOW (window),
@@ -996,6 +1062,9 @@ caja_window_finalize_menus (CajaWindow *window)
 
     g_signal_handlers_disconnect_by_func (caja_preferences,
                                           show_hidden_files_preference_callback, window);
+
+    g_signal_handlers_disconnect_by_func (caja_preferences,
+                                          show_backup_files_preference_callback, window);
 }
 
 static GList *
@@ -1046,20 +1115,24 @@ add_extension_menu_items (CajaWindow *window,
         CajaMenu *menu;
         GtkAction *action;
         char *path;
+        const gchar *action_name;
 
         item = CAJA_MENU_ITEM (l->data);
 
         g_object_get (item, "menu", &menu, NULL);
 
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         action = caja_action_from_menu_item (item, GTK_WIDGET (window));
         gtk_action_group_add_action_with_accel (action_group, action, NULL);
+        action_name = gtk_action_get_name (action);
+        G_GNUC_END_IGNORE_DEPRECATIONS;
 
         path = g_build_path ("/", POPUP_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
         gtk_ui_manager_add_ui (ui_manager,
                                merge_id,
                                path,
-                               gtk_action_get_name (action),
-                               gtk_action_get_name (action),
+                               action_name,
+                               action_name,
                                (menu != NULL) ? GTK_UI_MANAGER_MENU : GTK_UI_MANAGER_MENUITEM,
                                FALSE);
         g_free (path);
@@ -1068,8 +1141,8 @@ add_extension_menu_items (CajaWindow *window,
         gtk_ui_manager_add_ui (ui_manager,
                                merge_id,
                                path,
-                               gtk_action_get_name (action),
-                               gtk_action_get_name (action),
+                               action_name,
+                               action_name,
                                (menu != NULL) ? GTK_UI_MANAGER_MENU : GTK_UI_MANAGER_MENUITEM,
                                FALSE);
         g_free (path);
@@ -1082,7 +1155,9 @@ add_extension_menu_items (CajaWindow *window,
 
             children = caja_menu_get_items (menu);
 
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
             subdir = g_build_path ("/", subdirectory, "/", gtk_action_get_name (action), NULL);
+            G_GNUC_END_IGNORE_DEPRECATIONS;
             add_extension_menu_items (window,
                                       merge_id,
                                       action_group,
@@ -1118,9 +1193,13 @@ caja_window_load_extension_menus (CajaWindow *window)
 
     merge_id = gtk_ui_manager_new_merge_id (window->details->ui_manager);
     window->details->extensions_menu_merge_id = merge_id;
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("ExtensionsMenuGroup");
     window->details->extensions_menu_action_group = action_group;
+#ifdef ENABLE_NLS
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     gtk_ui_manager_insert_action_group (window->details->ui_manager, action_group, 0);
     g_object_unref (action_group); /* owned by ui manager */
 
@@ -1129,9 +1208,7 @@ caja_window_load_extension_menus (CajaWindow *window)
     if (items != NULL)
     {
         add_extension_menu_items (window, merge_id, action_group, items, "");
-
-        g_list_foreach (items, (GFunc) g_object_unref, NULL);
-        g_list_free (items);
+        g_list_free_full (items, g_object_unref);
     }
 }
 
