@@ -5,27 +5,24 @@
 
 #include "test.h"
 
-static const char pixbuf_name[] = "/usr/share/pixmaps/mate-about-logo.png";
-
-#define BG_COLOR 0xFFFFFF
-#define BG_COLOR_SPEC "white"
+static const char pixbuf_name[] = PIXBUFDIR "/mate-logo-white.svg";
 
 static const char *names[] =
 {
 	"Tomaso Albinoni",
-	"Isaac Albniz",
+	"Isaac Albéniz",
 	"Georges Bizet",
 	"Luigi Boccherini",
 	"Alexander Borodin",
 	"Johannes Brahms",
 	"Max Bruch",
 	"Anton Bruckner",
-	"Frdric Chopin",
+	"Frédéric Chopin",
 	"Aaron Copland",
 	"John Corigliano",
 	"Claude Debussy",
-	"Lo Delibes",
-	"Antonn Dvork",
+	"Léo Delibes",
+	"Antonín Dvorák",
 	"Edward Elgar",
 	"Manuel de Falla",
 	"George Gershwin",
